translate.convert.xliff2odf

Package translate :: Package convert :: Module xliff2odf |
[hide private]
[frames] | no frames]

# Module xliff2odf

source code

convert OpenDocument (ODF) files to Gettext PO localization files

Functions | [hide private]
first_child(unit_node) | source code
translate_odf(template, input_file) | source code
write_odf(xlf_data, template, output_file, dom_trees) | source code
convertxliff(input_file, output_file, template) reads in stdin using fromfileclass, converts using convertorclass, writes to stdout | source code
main(argv=None) | source code

Variables | [hide private]
| formats = `{('xlf', 'odt'):("odt", convertxliff), ('xlf', 'ods'`...``

Imports: cStringIO, zipfile, etree, factory, unit_tree, extract, generate, odf_shared, odf_io

Variables Details | [hide private]

  ### formats Value:
      {('xlf', 'odt'):("odt", convertxliff), ('xlf', 'ods'):("ods", convertx
      liff), ('xlf', 'odp'):("odp", convertxliff), ('xlf', 'odg'):("odg", co
      nvertxliff), ('xlf', 'odc'):("odc", convertxliff), ('xlf', 'odf'):("od
      f", convertxliff), ('xlf', 'odi'):("odi", convertxliff), ('xlf', 'odm'
      ):("odm", convertxliff), ('xlf', 'ott'):("ott", convertxliff), ('xlf',
       'ots'):("ots", convertxliff), ('xlf', 'otp'):("otp", convertxliff), (
      'xlf', 'otg'):("otg", convertxliff), ('xlf', 'otc'):("otc", convertxli
      ff), ('xlf', 'otf'):("otf", convertxliff), ('xlf', 'oti'):("oti", conv
      ...